@@ -373,8 +373,8 @@ class ImportMixin:
     # raise_error_to_debug = True     # debug模式
     raise_error_to_debug = False     # debug模式
 
-    bulk_size = 50000       # 批处理数量
-    # bulk_size = 3000       # 批处理数量
+    workers = 1  # 导入时启用的线程数
+    bulk_size = 100000       # 批处理数量, 已被workers取代
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -641,8 +641,15 @@ class ImportMixin:
                             raise e
 
                 n = df_rows
+
                 bulk_size = self.bulk_size
-                if n < bulk_size:
+                workers = self.workers
+                if workers:
+                    from math import ceil
+                    bulk_size = ceil(n // workers)
+                print(f'--- bulk_size: {bulk_size}, single_import_flag: {bulk_size and n < bulk_size}')
+
+                if bulk_size and n <= bulk_size:
                     check_df_format(self, df1, md_dc_ls, curr_id, start=0, end=df_rows, n=df_rows, tqdm_i=my_tqdm, info_dc=info_dc, q=None)
                 else:
                     a = np.arange(n)
@@ -651,7 +658,7 @@ class ImportMixin:
                     thread_ls = []
                     for start_end_i in start_end_ls:
                         thread_i = threading.Thread(target=check_df_format,
-                                                    args=(self, df1, md_dc_ls, curr_id, start_end_i, start_end_i + bulk_size, df_rows, my_tqdm, info_dc, q))
+                                                    args=(self, df1, md_dc_ls, start_end_i + curr_id, start_end_i, start_end_i + bulk_size, df_rows, my_tqdm, info_dc, q))
                         thread_ls.append(thread_i)
                         thread_i.start()
 
@@ -662,7 +669,9 @@ class ImportMixin:
                 print(f'*** df_rows: {df_rows} --- len(md_dc_ls): {len(md_dc_ls)}')
                 save_q = queue.Queue()
 
-                def save_md_dc_ls(md_dc_ls, start=0, end=None, n=None, tqdm_i=None, q=None):
+                def save_md_dc_ls(md_dc_ls, start=0, end=None, n=None, tqdm_i=None, q=None, pk_name=None):
+                    tt = Time()
+
                     n = len(md_dc_ls) if n is None else n
                     if not n:
                         return
@@ -673,13 +682,25 @@ class ImportMixin:
                         end = n
                     try:
                         for i in range(start, end):
+                            # print(start_end_i, start_end_i + bulk_size)
+                            # tt.sleep(0.1)
+
                             if self.CREATE_EXIST_FLAG:
                                 return
                             md_dc_i = md_dc_ls[i]
+
+                            # pk_value = -1
+                            # if pk_name not in md_dc_i and 'pk' not in md_dc_i:
+                            #     pk_value = start + i + 1
+                            #     # print(f'自定义pk!')
+                            #     md_dc_i.update({pk_name: pk_value})
+                            # print(f'~~~~~~', start, end, '~~~', i, pk_name, f' --- pk_value: {pk_value} --- md_dc_i: {md_dc_i}')
+
                             self.model.objects.create(**md_dc_i)  # `md_i.save()`不太好, 容易覆盖原有数据
                             if tqdm_i:
                                 tqdm_i.update(1)
                     except Exception as e:
+                        print(f'~~~~~~', start, end, '~~~', i, f'~~~ error: {e}', f'*** md_dc_i: {md_dc_i}')
                         if q is not None:
                             q.put(sys.exc_info())
                         else:
@@ -687,7 +708,7 @@ class ImportMixin:
 
                 from ..django.conf import db_engine
                 use_sqlite3 = 'sqlite3' in db_engine
-                if n < bulk_size or use_sqlite3:
+                if (bulk_size and n <= bulk_size) or use_sqlite3:
                     for i in range(len(md_dc_ls)):
                         md_dc_i = md_dc_ls[i]
                         save_tqdm.update(1)
@@ -699,9 +720,11 @@ class ImportMixin:
                     start_end_ls = list(a[s])
                     thread_ls = []
                     for start_end_i in start_end_ls:
-                        thread_i = threading.Thread(target=save_md_dc_ls, args=(md_dc_ls, start_end_i, start_end_i + bulk_size, n, save_tqdm, save_q))
+                        # print(start_end_i, start_end_i + bulk_size)
+                        thread_i = threading.Thread(target=save_md_dc_ls, args=(md_dc_ls, start_end_i, start_end_i + bulk_size, n, save_tqdm, save_q, pk_name))
                         thread_ls.append(thread_i)
                         thread_i.start()
+                        thread_i.join()
 
                     # self.CREATE_EXIST_FLAG = False
                     self.check_thread_ls(thread_ls, save_q, 'CREATE_EXIST_FLAG')
