@@ -9,6 +9,7 @@ from django.http import JsonResponse
 from django.contrib.contenttypes.models import ContentType
 from bddjango import convert_query_parameter_to_bool, my_api_assert_function
 from bddjango import find_indexes_in_dc_ls
+from bddjango import get_base_model
 
 
 tmp_urls = None
@@ -34,7 +35,11 @@ my_apps = get_my_apps()
 def get_layer_for_app_and_views():
     auto_dc_ls = []
     for app_label in my_apps:
-        exec(f'global tmp_views; from {app_label} import views as tmp_views;')
+        try:
+            exec(f'global tmp_views; from {app_label} import views as tmp_views;')
+        except Exception as e:
+            print(f'****** 从app_label[{app_label}]导入views出错... error: {e}')
+            continue
 
         views = tmp_views
         func_ls = dir(views)
@@ -85,6 +90,9 @@ def set_options(ls):
     ContentTypeAdmin.auto_wiki.layer['params'][0]['options'] = options
 
 
+from bddjango import get_field_names_by_model
+
+
 class ContentTypeAdmin(BaseAdmin):
     """
     # 自动生成代码和wiki的admin
@@ -95,12 +103,30 @@ class ContentTypeAdmin(BaseAdmin):
         - app_filter: app_label过滤器
     """
 
+    ordering = ['app_label', 'model']
     app_filter = my_apps
     app_exclude = []
 
+    list_display = get_field_names_by_model(ContentType) + ['get_object_name', 'get_model_verbose_name']
     list_filter = ['app_label']
     actions = ['auto_wiki', 'auto_code', 'auto_model']
 
+    def get_object_name(self, obj):
+        base_model = get_base_model(obj)
+        ret = base_model._meta.object_name
+        return ret
+
+    get_object_name.short_description = '模型对象名'
+    get_object_name.allow_tags = True
+
+    def get_model_verbose_name(self, obj):
+        base_model = get_base_model(obj)
+        ret = base_model._meta.verbose_name
+        return ret
+
+    get_model_verbose_name.short_description = '模型别名'
+    get_model_verbose_name.allow_tags = True
+
     default_export_action = False
     custom_import_and_export_buttons = False  # 是否显示自定义的导入导出按钮
     has_import_perm = False  # 导入数据
@@ -536,7 +562,7 @@ class ContentTypeAdmin(BaseAdmin):
     }
 
 
-def register_content_type_admin(app_filter=None, app_exclude=None, list_filter=None,
+def register_content_type_admin(ordering=None, app_filter=None, app_exclude=None, list_filter=None,
                                 default_use_complete_model_view=None, add_db_column=None):
     """
     自动注册content_type_admin
@@ -550,6 +576,8 @@ def register_content_type_admin(app_filter=None, app_exclude=None, list_filter=N
     --- eg:
     >>>　register_content_type_admin(default_use_complete_model_view=1, add_db_column=0)
     """
+    if ordering is not None:
+        ContentTypeAdmin.ordering = ordering
     if app_filter is not None:
         ContentTypeAdmin.app_filter = app_filter
     if app_exclude is not None:
