@@ -826,7 +826,8 @@ def get_total_occurrence_times_by_keywords(total_qs_ls, search_field_ls, keyword
     return ret
 
 
-def get_statistic_fields_result(queryset, statistic_fields, statistic_size=5, descend=True):
+
+def get_statistic_fields_result(queryset, statistic_fields, statistic_size=5, descend=True, order_config_dc_ls=None):
     """
     # 统计字段 fields 的值各出现了几次
     - statistic_fields 为迭代型时(如[name, id]), 只统计第一个字段, 然后将第二个字段用filter补上一个值
@@ -840,6 +841,19 @@ def get_statistic_fields_result(queryset, statistic_fields, statistic_size=5, de
     else:
         ordering = ['counts']
 
+    order_df = None
+    if order_config_dc_ls:
+        _order_config_dc_i = {
+            'name': None,
+            'ordering': None,
+            'pop_name_ls': None
+        }
+        order_config_dc_ls.insert(0, _order_config_dc_i)
+        order_df = pd.DataFrame(order_config_dc_ls)
+        order_df = order_df.set_index('name')
+        # Drop rows with a NaN index
+        order_df = order_df.drop(order_df.index[order_df.index.isna()])
+
     statistic_dc = {}
     for field in statistic_fields:
         # break
@@ -850,15 +864,37 @@ def get_statistic_fields_result(queryset, statistic_fields, statistic_size=5, de
         else:
             field_qsv = queryset.values(field)
             dc_name = field
-        statistic_qsv = field_qsv.annotate(counts=m.Count('pk')).order_by(*ordering)
+
+        if order_df is not None and dc_name in order_df.index:
+            _ordering = order_df.loc[dc_name][0]
+            _ordering = [_ordering] if isinstance(_ordering, str) else _ordering
+            _ordering = ordering if pd.isna(_ordering) else _ordering
+
+            pop_name_ls = order_df.loc[dc_name][1]
+            pop_name_ls = [pop_name_ls] if isinstance(pop_name_ls, str) else pop_name_ls
+            pop_name_ls = None if pd.isna(pop_name_ls) else pop_name_ls
+
+            if pop_name_ls:
+                field_qsv = field_qsv.exclude(**{f'{dc_name}__in': pop_name_ls})
+            statistic_qsv = field_qsv.annotate(counts=m.Count('pk')).order_by(*_ordering)
+        else:
+            statistic_qsv = field_qsv.annotate(counts=m.Count('pk')).order_by(*ordering)
+
+        # if order_by_self_descend_ls and dc_name in order_by_self_descend_ls:
+        #     # statistic_qsv = field_qsv.annotate(counts=m.Count('pk')).order_by(f'-{dc_name}')
+        #     statistic_qsv = field_qsv.annotate(counts=m.Count('pk')).order_by(_ordering)
+        # else:
+        #     statistic_qsv = field_qsv.annotate(counts=m.Count('pk')).order_by(*ordering)
         dc_ls = list(statistic_qsv[:statistic_size])
 
         for dc in dc_ls:
             if isinstance(field, (tuple, list)):
                 dc['name'] = dc.pop(field[0])
-                f_name = field[1]
-                f_value = queryset.filter(**{field[0]: dc['name']}).order_by(f_name).values(f_name)[0].get(f_name)
-                dc[f_name] = f_value
+                for f_name in field[1:]:
+                    # f_name = field[1]
+                    obj = queryset.filter(**{field[0]: dc['name']}).order_by(f_name).values(f_name)[0]
+                    f_value = obj.get(f_name)
+                    dc[f_name] = f_value
             else:
                 dc['name'] = dc.pop(field)
         dc = {
