@@ -1,7 +1,6 @@
 from .utils import *
 from rest_framework.views import APIView
 from .mixins import MyCreateModelMixin, MyUpdateModelMixin, MyDestroyModelMixin
-from .conf import db_engine
 
 
 class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
@@ -661,3 +660,47 @@ class CompleteModelView(BaseListView, MyCreateModelMixin, MyUpdateModelMixin, My
         ret, status, msg = self.get_list_ret(request, *args, **kwargs)
         return APIResponse(ret, status=status, msg=msg)
 
+
+class AddTimes(APIView):
+    """
+    # 推荐次数加一
+
+    - 指定model和pk, 其field_name对应的times加一.
+    - model_name默认为Question, 取值范围md_dc.
+    - field_name默认为view_times字段, 取值范围field_name_ls.
+
+    GET /api/index/AddTimes/?model_name=Law&id=3&field_name=view_times  # 指定id为3的Law对象, 其view_times字段加1
+    """
+    default_model_name = None  # 默认模型名
+    md_dc = None  # 可选择的模型名字典, 如{'Law': models.Law}
+    default_field_name = None  # 默认字段名
+    field_name_ls = None  # 可选择的字段范围, 如["view_times", "download_times"]等
+
+    delta = 1  # 默认加1
+
+    def get(self, request):
+        query_dc = request.GET
+        pk = query_dc.get('pk') or query_dc.get('id')
+        model_name = query_dc.get('model_name', self.default_model_name)
+        field_name = query_dc.get('field_name', self.default_field_name)
+
+        field_name_ls = self.field_name_ls
+        md_dc = self.md_dc
+        assert md_dc is not None, 'md_dc必须初始化!'
+        assert field_name_ls is not None, 'field_name_ls必须初始化!'
+
+        my_api_assert_function(field_name in field_name_ls, f'field_name 取值范围: {field_name_ls}')
+
+        md = md_dc.get(model_name)
+        my_api_assert_function(md, f'`model_name`参数取值范围: {list(md_dc.keys())}')
+        objs = md.objects.filter(pk=pk)
+        my_api_assert_function(objs.count(), f'未找到id={pk}!')
+        obj = objs[0]
+        times = getattr(obj, field_name)
+        if times is None:
+            times = 0
+        times_ = times + self.delta
+        setattr(obj, field_name, times_)
+        obj.save()
+        return APIResponse(None, msg=f"{model_name}__{field_name}: {times_}")
+
